@@ -31,11 +31,11 @@ Service Service::tcp;
 bool Service::active = false;
 
 Service::Service() :
-BayonneService(-1, 0), Keydata(Bayonne::getKeypath(KEYS))
+BayonneService(0, 0), Keydata(Bayonne::getKeypath(KEYS))
 {
 	static Keydata::Define defkeys[] = {
-	{"interface", "127.0.0.1"},
-	{"port", "5555"},
+	{"interface", "127.0.0.1:5555"},
+	{"gateway", "127.0.0.1:5556"},
 	{"secret", "pass"},
 	{NULL, NULL}};
 
@@ -63,10 +63,25 @@ void Service::stopService(void)
 
 void Service::run(void)
 {
-	InetAddress addr(getLast("interface"));
-	tpport_t port = atoi(getLast("port"));
-	TCPSocket tcp(addr, port);
+	tpport_t port;
 	Session *session;
+	char *abuf;
+	char *pnum;
+
+	if(Bayonne::provision_gateway)
+		abuf = (char *)getLast("gateway");
+	else
+		abuf = (char *)getLast("interface");
+
+	pnum = strrchr(abuf, ':');
+	if(pnum)
+		*(pnum++) = 0;
+	else
+		pnum = "5555";
+
+	port = atoi(pnum);
+	InetAddress addr(abuf);
+	TCPSocket tcp(addr, port);
 
 	active = true;
 	slog.debug("tcpmon service started");
