@@ -124,6 +124,11 @@ public class Libexec
 		}	
 	}
 
+	public void postSymbol(String id, String value) {
+		String sid = getHead("SESSION");
+		System.out.println(sid + " POST " + id + " " + value);
+	}		
+
 	public String getPosition() {
 		return _position;
 	}
